@@ -20,6 +20,7 @@ from numpy import ma
 
 try:
     import netCDF4
+    from netCDF4 import date2num
 except:
     import pupynere
 from pydap.client import open_url
@@ -135,10 +136,8 @@ class AVISO_fetch(object):
         #logger.warn("warn message")
         #logger.error("error message")
         #logger.critical("critical message")
-
         self.logger = logger
 
-
     def set_source_filename(self, map):
         """
         """
@@ -156,7 +155,7 @@ class AVISO_fetch(object):
 
         if var == 'h':
             url = "%s/%s-h" % (self.cfg['urlbase'], self.cfg['source_filename'])
-        if var in ['u', 'v']:
+        elif var in ['u', 'v']:
             url = "%s/%s-uv" % (self.cfg['urlbase'], self.cfg['source_filename'])
 
         ntries = 40
@@ -177,12 +176,13 @@ class AVISO_fetch(object):
         """
         self.logger.debug("Downloading time")
         t = dataset['time'][:]
-        # Improve it and extract this date from the DAP server
-        d0=datetime(1950,1,1)
         if 't_ini' not in self.cfg['limits']:
             if 'd_ini' in self.cfg['limits']:
-                d = datetime.strptime(self.cfg['limits']['d_ini'], '%Y-%m-%d')
-                self.cfg['limits']['t_ini'] = np.nonzero(t>=((d-d0).days*24))[0][0]
+                assert type(self.cfg['limits']['d_ini']) == datetime, \
+                        "limits:d_ini must be a datetime"
+                d = date2num(self.cfg['limits']['d_ini'],
+                        dataset['time'].attributes['units'])
+                self.cfg['limits']['t_ini'] = np.nonzero(t>=d)[0][0]
             else:
                 self.cfg['limits']['t_ini'] = 0
                 self.logger.debug("Setting t_ini: %s" % self.cfg['limits']['t_ini'])
@@ -193,8 +193,11 @@ class AVISO_fetch(object):
 
         if 't_fin' not in self.cfg['limits']:
             if 'd_fin' in self.cfg['limits']:
-                d = datetime.strptime(self.cfg['limits']['d_fin'], '%Y-%m-%d')
-                self.cfg['limits']['t_fin'] = np.nonzero(t>((d-d0).days*24))[0][0]
+                assert type(self.cfg['limits']['d_fin']) == datetime, \
+                        "limits:d_ini must be a datetime"
+                d = date2num(self.cfg['limits']['d_fin'],
+                        dataset['time'].attributes['units'])
+                self.cfg['limits']['t_fin'] = np.nonzero(t>d)[0][0]
             else:
                 self.cfg['limits']['t_fin'] = dataset['time'].shape[0]
                 self.logger.debug("Setting t_fin: %s" % self.cfg['limits']['t_fin'])
@@ -261,11 +264,11 @@ class AVISO_fetch(object):
         self.slice_size = lon.shape[0]*lat.shape[0]
 
         # ========
-        self.nc.createDimension('lat', lat.shape[0])
-        self.nc.createDimension('lon', lon.shape[0])
+        self.nc.createDimension('latitude', lat.shape[0])
+        self.nc.createDimension('longitude', lon.shape[0])
 
-        ncLat = self.nc.createVariable('Lat', 'f4', ('lat', 'lon'))
-        ncLon = self.nc.createVariable('Lon', 'f4', ('lat', 'lon'))
+        ncLat = self.nc.createVariable('Lat', 'f4', ('latitude', 'longitude'))
+        ncLon = self.nc.createVariable('Lon', 'f4', ('latitude', 'longitude'))
 
         ncLat[:] = Lat
         ncLon[:] = Lon
@@ -324,7 +327,7 @@ class AVISO_fetch(object):
             self.logger.info("Getting %s" % v)
             #data['h'] = ma.masked_all((len(ti),Lonlimits[-1]-Lonlimits[0], Latlimits[-1]-Latlimits[0]), dtype=numpy.float64)
             #dataset.type.typecode
-            data = self.nc.createVariable(v, 'i4', ('time', 'lat', 'lon'),
+            data = self.nc.createVariable(v, 'i4', ('time', 'latitude', 'longitude'),
                     fill_value=attr['_FillValue'])
             missing_value = attr['_FillValue']
             #data.missing_value = missing_value
@@ -362,7 +365,7 @@ class AVISO_fetch(object):
                             tmp2 = dataset[b1:b2:self.cfg['limits']['t_step'],
                                     Latlimits[0]:Latlimits[-1]+1,
                                     :Lonlimits[-1]+1]
-                            tmp = np.append(tmp1, tmp2, axis=1)
+                            tmp = np.append(tmp1, tmp2, axis=2)
 
                         if factor is not None:
                             ind_valid = tmp != missing_value
@@ -400,9 +403,9 @@ class Products(object):
         except:
             return
 
-        W = self.nc.createVariable('W', 'f4', ('time', 'lat', 'lon'))
+        W = self.nc.createVariable('W', 'f4', ('time', 'latitude', 'longitude'))
         W.missing_value = self.nc.variables['u'].missing_value
-        zeta = self.nc.createVariable('zeta', 'f4', ('time', 'lat', 'lon'))
+        zeta = self.nc.createVariable('zeta', 'f4', ('time', 'latitude', 'longitude'))
         zeta.missing_value = self.nc.variables['u'].missing_value
 
         for tn in range(self.nc.variables['time'].size):
@@ -544,7 +547,7 @@ def mask_shallow(ncfile, zfile, zlimit):
     z = get_bathymery(Lat, Lon, etopo_file=zfile)
     ind = z > zlimit
     for v in nc.variables.keys():
-        if nc.variables[v].dimensions == (u'time', u'lat', u'lon'):
+        if nc.variables[v].dimensions == (u'time', u'latitude', u'longitude'):
             if nc.variables[v].shape[1:] != ind.shape:
                 return
             I, J = np.nonzero(ind)
